@@ -63,3 +63,18 @@ def display_code(content):
 def display_iframe(url):
     from IPython.display import IFrame
     return IFrame(src = url, width = "100%", height=300)
+
+def get_file_md5sum(file):
+    import hashlib
+    import os
+    if not os.path.exists(file):
+        return "md5sum: {}: No such file or directory".format(file)
+    elif os.path.isdir(file):
+        return "md5sum: {}: Is a directory".format(file)
+    elif os.path.isfile(file):
+        with open(file, 'rb') as fd:
+            data = fd.read()
+        #return "{}  {}".format(hashlib.md5(data).hexdigest(), file)
+        return hashlib.md5(data).hexdigest()
+    else:
+        return "md5sum: {}: Unexpected error".format(file)
